==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Downloads/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Edellinen sivu");
define("_NEXT","Uusi sivu");
define("_CATEGORY","Kategoria");

 
define("_CATEGORIES","Aihepiirit");
define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_THEREARE","Tietokannassa on");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_SCOMMENTS","Kommentit");
define("_UNKNOWN","tuntematon");
define("_DOWNLOADS","imurointia"); 
define("_AUTHORNAME","Nimi");
define("_AUTHOREMAIL","Shkposti");
define("_DOWNLOADNAME","Tiedoston nimi");
define("_ADDTHISFILE","Lis tiedosto");
define("_INBYTES","kt");
define("_FILESIZE","tiedostokoko");
define("_VERSION","Versio");
define("_DESCRIPTION","Kuvaus");
define("_AUTHOR","Nimi");
define("_HOMEPAGE","Kotisivut");
define("_DOWNLOADNOW","Imuroi tm tiedosto!");
define("_RATERESOURCE","Arvostele");
define("_FILEURL","Tiedoston URL");
define("_ADDDOWNLOAD","Lis tiedosto");
define("_DOWNLOADSMAIN","Etusivu");
define("_DOWNLOADCOMMENTS","Kommentit");
define("_DOWNLOADSMAINCAT","Kategoriat");
define("_ADDADOWNLOAD","Lis tiedosto");
define("_DSUBMITONCE","Lis tiedosto vain kerran.");
define("_DPOSTPENDING","Kaikki tiedostot hyvksytetn yllpitjll ennen niiden julkaisemista.");
define("_RESSORTED","Lajiteltu");
define("_DOWNLOADSNOTUSER1","Et ole joko rekisteritynyt tai kirjautunut.");
define("_DOWNLOADSNOTUSER2","Rekisterityneen kyttjn sinulla on mahdollisuus list tiedostoja sivuille");
define("_DOWNLOADSNOTUSER3","Rekisterityminen on helppoa ja vaivatonta.");
define("_DOWNLOADSNOTUSER4","Miksi me vaadimme kytttjimme rekisteritymn?");
define("_DOWNLOADSNOTUSER5","Jotta voimme antaa teille parhaimman laadun,");
define("_DOWNLOADSNOTUSER6","kaikki tiedostot ovat tarkistettuja ja yllpitjn hyvksymi.");
define("_DOWNLOADSNOTUSER7","Pyrimme mys tarjoamaan tarpeellisen tiedon tiedostosta.");
define("_DOWNLOADSNOTUSER8","<a href=\"user.php?new_user\">rekisteridy</a> (tai kirjaudu)");
define("_DOWNLOADALREADYEXT","VIRHE: Tiedosto lytyy jo tietokannastamme!");
define("_DOWNLOADNOTITLE","VIRHE: Annappas tiedostolle nimi!");
define("_DOWNLOADNOURL","VIRHE: URL unohtui!");
define("_DOWNLOADNODESC","VIRHE: Kuvaus unohtui!");
define("_DOWNLOADRECEIVED","Me saimme tiedoston hyvksyttvksi - kiitos!");
define("_NEWDOWNLOADS","Uudet");
define("_TOTALNEWDOWNLOADS","Uusia");
define("_DTOTALFORLAST","Uudet tiedostot viimeiselt");
define("_DBESTRATED","Eniten ni - TOP ");
define("_TRATEDDOWNLOADS","ni kaikkiaan");
define("_SORTDOWNLOADSBY","Lajittele");
define("_DCATNEWTODAY","Uudet tiedostot, jotka on listty tnn");
define("_DCATLAST3DAYS","Uudet tiedostot, jotka ovat listty viimeisen 3 pivn aikana");
define("_DCATTHISWEEK","Uudet tiedostot, jotka listty tll viikolla");
define("_DDATE1","Piv (Vanhat ensimmisen)");
define("_DDATE2","Piv (Uudet ensimmisen)");
define("_DOWNLOADPROFILE","Profiili");
define("_DOWNLOADRATINGDET","Arvostelujen tiedot");
define("_EDITTHISDOWNLOAD","Muokkaa");
define("_DOWNLOADRATING","Arvostelut");
define("_DOWNLOADVOTE","Arvostele!");
define("_REQUESTDOWNLOADMOD","Muokkaa");
define("_DOWNLOADID","ID");
define("_DLETSDECIDE","Juuri nitten arvostelujen perusteella muut surffaajat voivat paremmin ptt mit itse tahtovat imuroida.");
define("_DRATENOTE4","Katso <a href=\"modules.php?name=Downloads&d_op=TopRated\">Parhaat net</a>.");
define("_DATE","Piv");
define("_TO","Kenelle:");
define("_NEW","Uusi");
define("_POPULAR","Suosittu");
define("_TOPRATED","Huippuluokiteltu");
define("_ADDITIONALDET","Listiedot");
define("_EDITORREVIEW","Toimittajan valinnat");
define("_REPORTBROKEN","Ilmoita toimimattomasta linkist");
define("_AND","ja");
define("_INDB","kannassamme");
define("_INSTRUCTIONS","Ohjeet");
define("_USERANDIP","Kyttjtunnus ja IP talletetaan, joten ethn kyt jrjestelm vrin.");
define("_LDESCRIPTION","Kuvaus: (255 merkki max)");
define("_CHECKFORIT","Et kirjoittanut shkpostiosoitettasi. Tarkistamme kuitenkin linkkisi pian.");
define("_LASTWEEK","viime viikolta");
define("_LAST30DAYS","viimeisilt 30 pivlt");
define("_1WEEK","1 viikon ajalta");
define("_2WEEKS","2 viikon ajalta");
define("_30DAYS","30 pivn ajalta");
define("_SHOW","Nyt");
define("_DAYS","pivlt");
define("_ADDEDON","listty");
define("_RATING","Sija");
define("_DETAILS","Yksityiskohdat");
define("_OF","of");
define("_TVOTESREQ","nten mrn minimi");
define("_SHOWTOP","Nyt Top");
define("_MOSTPOPULAR","Suosituimmat - Top");
define("_OFALL","kaikista");
define("_POPULARITY","Suosio");
define("_SELECTPAGE","Valitse sivu");
define("_MAIN","Etusivu");
define("_NEWTODAY","Uusia tnn");
define("_NEWLAST3DAYS","Uudet viimeisten 3 pivn ajalta");
define("_NEWTHISWEEK","Uudet tlt viikolta");
define("_POPULARITY1","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_POPULARITY2","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_TITLEAZ","Otsikko (A - Z)");
define("_TITLEZA","Otsikko (Z - A)");
define("_RATING1","Tila (Viimeisest ensimmiseen)");
define("_RATING2","Tila (Ensimmisest viimeiseen)");
define("_SEARCHRESULTS4","Hakutulokset");
define("_USUBCATEGORIES","Alakategoriat");
define("_TRY2SEARCH","Yrit etsi");
define("_INOTHERSENGINES","muilla hakukoneilla");
define("_EDITORIAL","Kommentti");
define("_EDITORIALBY","Kommentoinut:");
define("_NOEDITORIAL","Tlle sivulle ei tll hetkell ole kommenttia.");
define("_RATETHISSITE","Arvostele tt lhdett");
define("_ISTHISYOURSITE","Onko tm lhteesi?");
define("_ALLOWTORATE","Anna muiden kyttjien arvostella sit omalta sivultasi!");
define("_OVERALLRATING","Yleisarvostelu");
define("_TOTALOF","Yhteens");
define("_USER","Kyttj");
define("_USERAVGRATING","Kyttjn keskimrinen sija");
define("_NUMRATINGS","nien mr");
define("_REGISTEREDUSERS","Rekisterityneet kyttjt");
define("_NUMBEROFRATINGS","nien mr");
define("_NOREGUSERSVOTES","Ei rekisterityneiden kyttjien ni");
define("_BREAKDOWNBYVAL","Sijoituksien erittely arvostelun mukaan");
define("_LTOTALVOTES","yhteens ni");
define("_HIGHRATING","Korkea sija");
define("_LOWRATING","Huono sija");
define("_NUMOFCOMMENTS","Kommenttien mr");
define("_WEIGHNOTE","* Huom: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien kyttjien arvostelut");
define("_NOUNREGUSERSVOTES","Ei rekisteritymttmien kyttjien ni");
define("_WEIGHOUTNOTE","* Huom.: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien nestjien arvostelut");
define("_NOOUTSIDEVOTES","Ei ulkopuolisten ni");
define("_OUTSIDEVOTERS","Ulkopuoliset nestjt");
define("_UNREGISTEREDUSERS","Rekisteritymttmt kyttjt");
define("_PROMOTEYOURSITE","Mainosta sivuasi");
define("_PROMOTE01","Voit ehk olla kiinnostunut etisist 'Arvostele sivua' vaihtoehdoistamme. Ne antavat sinulle mahdollisuuden laittaa kuvan (tai jopa arvostelun) sivullesi kasvattamaan lhteesi nien mr. Valitse yhdest alla listatuista vaihtosehdoista:");
define("_TEXTLINK","Tekstilinkki");
define("_PROMOTE02","Yksi tapa linkitt arvostelukaavakkeeseen on yksinkertainen tekstilinkki:");
define("_HTMLCODE1","HTML-koodi, jota sinun tulisi tss tapauksessa kytt, on seuraava:");
define("_THENUMBER","Mr");
define("_IDREFER","HTML-lhdekoodissa viitataan sivusi tunnusnumeroon $sivunimi -tietokannassa. Varmista ett tm numero on mainittu.");
define("_BUTTONLINK","Nappilinkki");
define("_PROMOTE03","Jos etsit jotain muuta kuin tekstilinkki, saatat haluta kytt pient nappilinkki:");
define("_RATEIT","Arvostele tt sivua!");
define("_HTMLCODE2","Lhdekoodi edell mainitulle napille on:");
define("_REMOTEFORM","Ethallittu arvostelulomake");
define("_PROMOTE04","Jos huijaat tss, poistamme linkkisi. Tlt nytt nykyinen ethallittu arvostelulomake.");
define("_VOTE4THISSITE","nest tt sivua!");
define("_HTMLCODE3","Kytten tt lomaketta kyttjt voivat arvostella sivuasi suoraan sivultasi ja arvostelu talletetaan tnne. Ylloleva lomake ei toimi, mutta seuraava lhdekoodi toimii jos yksinkertaisesti leikkaat ja liimaat sen nettisivuusi. Lhdekoodi nkyy alla:");
define("_PROMOTE05","Kiitos! ja onnea arvosteluillesi!");
define("_STAFF","Yllpito");
define("_THANKSBROKEN","Kiitos ett autoit pitmn yll tmn luettelon kokonaisuutta.");
define("_SECURITYBROKEN","Turvallisuussyist kyttjtunnuksesi ja IP-osoitteesi talletetaan vkiaikaisesti.");
define("_THANKSFORINFO","Kiitos tiedoista.");
define("_LOOKTOREQUEST","Tarkistamme toiveesi pian.");
define("_SENDREQUEST","Lhet ehdotus");
define("_THANKSTOTAKETIME","Kiitos ajan kytstsi sivun arvosteluun tll");
define("_RETURNTO","Palaa");
define("_RATENOTE1","l nest samaa lhdett enemp kuin kerran.");
define("_RATENOTE2","Asteikko on 1 - 10, jossa 1 on huono ja 10 erinomainen.");
define("_RATENOTE3","Ole puolueeton nestyksesssi, jos kaikki saavat 1 tai 10, arvosteluista ei ole paljonkaan hyty.");
define("_RATENOTE5","l nest oman tai kilpailijasi lhteest.");
define("_YOUAREREGGED","Olet rekisterity kyttj ja olet kirjautunut sisn.");
define("_FEELFREE2ADD","Laita vapaasti kommentti tlle sivulle.");
define("_YOUARENOTREGGED","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_IFYOUWEREREG","Jos olisit rekisteritynyt, voisit kommetoida tt sivua.");
define("_TITLE","Otsikko");
define("_MODIFY","Muokkaa");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Downloads/language/lang-finnish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","URL");
define("_PREVIOUS","Edellinen sivu");
define("_NEXT","Uusi sivu");
define("_CATEGORY","Kategoria");

 
define("_CATEGORIES","Aihepiirit");
define("_LVOTES","nt");
define("_TOTALVOTES","ni :");
define("_THEREARE","Tietokannassa on");
define("_NOMATCHES","Tietoja antamillasi hakuehdoilla ei lytynyt");
define("_SCOMMENTS","Kommentit");
define("_UNKNOWN","tuntematon");
define("_DOWNLOADS","imurointia"); 
define("_AUTHORNAME","Nimi");
define("_AUTHOREMAIL","Shkposti");
define("_DOWNLOADNAME","Tiedoston nimi");
define("_ADDTHISFILE","Lis tiedosto");
define("_INBYTES","kt");
define("_FILESIZE","tiedostokoko");
define("_VERSION","Versio");
define("_DESCRIPTION","Kuvaus");
define("_AUTHOR","Nimi");
define("_HOMEPAGE","Kotisivut");
define("_DOWNLOADNOW","Imuroi tm tiedosto!");
define("_RATERESOURCE","Arvostele");
define("_FILEURL","Tiedoston URL");
define("_ADDDOWNLOAD","Lis tiedosto");
define("_DOWNLOADSMAIN","Etusivu");
define("_DOWNLOADCOMMENTS","Kommentit");
define("_DOWNLOADSMAINCAT","Kategoriat");
define("_ADDADOWNLOAD","Lis tiedosto");
define("_DSUBMITONCE","Lis tiedosto vain kerran.");
define("_DPOSTPENDING","Kaikki tiedostot hyvksytetn yllpitjll ennen niiden julkaisemista.");
define("_RESSORTED","Lajiteltu");
define("_DOWNLOADSNOTUSER1","Et ole joko rekisteritynyt tai kirjautunut.");
define("_DOWNLOADSNOTUSER2","Rekisterityneen kyttjn sinulla on mahdollisuus list tiedostoja sivuille");
define("_DOWNLOADSNOTUSER3","Rekisterityminen on helppoa ja vaivatonta.");
define("_DOWNLOADSNOTUSER4","Miksi me vaadimme kytttjimme rekisteritymn?");
define("_DOWNLOADSNOTUSER5","Jotta voimme antaa teille parhaimman laadun,");
define("_DOWNLOADSNOTUSER6","kaikki tiedostot ovat tarkistettuja ja yllpitjn hyvksymi.");
define("_DOWNLOADSNOTUSER7","Pyrimme mys tarjoamaan tarpeellisen tiedon tiedostosta.");
define("_DOWNLOADSNOTUSER8","<a href=\"user.php?new_user\">rekisteridy</a> (tai kirjaudu)");
define("_DOWNLOADALREADYEXT","VIRHE: Tiedosto lytyy jo tietokannastamme!");
define("_DOWNLOADNOTITLE","VIRHE: Annappas tiedostolle nimi!");
define("_DOWNLOADNOURL","VIRHE: URL unohtui!");
define("_DOWNLOADNODESC","VIRHE: Kuvaus unohtui!");
define("_DOWNLOADRECEIVED","Me saimme tiedoston hyvksyttvksi - kiitos!");
define("_NEWDOWNLOADS","Uudet");
define("_TOTALNEWDOWNLOADS","Uusia");
define("_DTOTALFORLAST","Uudet tiedostot viimeiselt");
define("_DBESTRATED","Eniten ni - TOP ");
define("_TRATEDDOWNLOADS","ni kaikkiaan");
define("_SORTDOWNLOADSBY","Lajittele");
define("_DCATNEWTODAY","Uudet tiedostot, jotka on listty tnn");
define("_DCATLAST3DAYS","Uudet tiedostot, jotka ovat listty viimeisen 3 pivn aikana");
define("_DCATTHISWEEK","Uudet tiedostot, jotka listty tll viikolla");
define("_DDATE1","Piv (Vanhat ensimmisen)");
define("_DDATE2","Piv (Uudet ensimmisen)");
define("_DOWNLOADPROFILE","Profiili");
define("_DOWNLOADRATINGDET","Arvostelujen tiedot");
define("_EDITTHISDOWNLOAD","Muokkaa");
define("_DOWNLOADRATING","Arvostelut");
define("_DOWNLOADVOTE","Arvostele!");
define("_REQUESTDOWNLOADMOD","Muokkaa");
define("_DOWNLOADID","ID");
define("_DLETSDECIDE","Juuri nitten arvostelujen perusteella muut surffaajat voivat paremmin ptt mit itse tahtovat imuroida.");
define("_DRATENOTE4","Katso <a href=\"modules.php?name=Downloads&d_op=TopRated\">Parhaat net</a>.");
define("_DATE","Piv");
define("_TO","Kenelle:");
define("_NEW","Uusi");
define("_POPULAR","Suosittu");
define("_TOPRATED","Huippuluokiteltu");
define("_ADDITIONALDET","Listiedot");
define("_EDITORREVIEW","Toimittajan valinnat");
define("_REPORTBROKEN","Ilmoita toimimattomasta linkist");
define("_AND","ja");
define("_INDB","kannassamme");
define("_INSTRUCTIONS","Ohjeet");
define("_USERANDIP","Kyttjtunnus ja IP talletetaan, joten ethn kyt jrjestelm vrin.");
define("_LDESCRIPTION","Kuvaus: (255 merkki max)");
define("_CHECKFORIT","Et kirjoittanut shkpostiosoitettasi. Tarkistamme kuitenkin linkkisi pian.");
define("_LASTWEEK","viime viikolta");
define("_LAST30DAYS","viimeisilt 30 pivlt");
define("_1WEEK","1 viikon ajalta");
define("_2WEEKS","2 viikon ajalta");
define("_30DAYS","30 pivn ajalta");
define("_SHOW","Nyt");
define("_DAYS","pivlt");
define("_ADDEDON","listty");
define("_RATING","Sija");
define("_DETAILS","Yksityiskohdat");
define("_OF","of");
define("_TVOTESREQ","nten mrn minimi");
define("_SHOWTOP","Nyt Top");
define("_MOSTPOPULAR","Suosituimmat - Top");
define("_OFALL","kaikista");
define("_POPULARITY","Suosio");
define("_SELECTPAGE","Valitse sivu");
define("_MAIN","Etusivu");
define("_NEWTODAY","Uusia tnn");
define("_NEWLAST3DAYS","Uudet viimeisten 3 pivn ajalta");
define("_NEWTHISWEEK","Uudet tlt viikolta");
define("_POPULARITY1","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_POPULARITY2","Suosio (Vhiten suosituista eniten suosittuihin)");
define("_TITLEAZ","Otsikko (A - Z)");
define("_TITLEZA","Otsikko (Z - A)");
define("_RATING1","Tila (Viimeisest ensimmiseen)");
define("_RATING2","Tila (Ensimmisest viimeiseen)");
define("_SEARCHRESULTS4","Hakutulokset");
define("_USUBCATEGORIES","Alakategoriat");
define("_TRY2SEARCH","Yrit etsi");
define("_INOTHERSENGINES","muilla hakukoneilla");
define("_EDITORIAL","Kommentti");
define("_EDITORIALBY","Kommentoinut:");
define("_NOEDITORIAL","Tlle sivulle ei tll hetkell ole kommenttia.");
define("_RATETHISSITE","Arvostele tt lhdett");
define("_ISTHISYOURSITE","Onko tm lhteesi?");
define("_ALLOWTORATE","Anna muiden kyttjien arvostella sit omalta sivultasi!");
define("_OVERALLRATING","Yleisarvostelu");
define("_TOTALOF","Yhteens");
define("_USER","Kyttj");
define("_USERAVGRATING","Kyttjn keskimrinen sija");
define("_NUMRATINGS","nien mr");
define("_REGISTEREDUSERS","Rekisterityneet kyttjt");
define("_NUMBEROFRATINGS","nien mr");
define("_NOREGUSERSVOTES","Ei rekisterityneiden kyttjien ni");
define("_BREAKDOWNBYVAL","Sijoituksien erittely arvostelun mukaan");
define("_LTOTALVOTES","yhteens ni");
define("_HIGHRATING","Korkea sija");
define("_LOWRATING","Huono sija");
define("_NUMOFCOMMENTS","Kommenttien mr");
define("_WEIGHNOTE","* Huom: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien kyttjien arvostelut");
define("_NOUNREGUSERSVOTES","Ei rekisteritymttmien kyttjien ni");
define("_WEIGHOUTNOTE","* Huom.: Tm lhde punnitsee rekisterityjen vs. rekisteritymttmien nestjien arvostelut");
define("_NOOUTSIDEVOTES","Ei ulkopuolisten ni");
define("_OUTSIDEVOTERS","Ulkopuoliset nestjt");
define("_UNREGISTEREDUSERS","Rekisteritymttmt kyttjt");
define("_PROMOTEYOURSITE","Mainosta sivuasi");
define("_PROMOTE01","Voit ehk olla kiinnostunut etisist 'Arvostele sivua' vaihtoehdoistamme. Ne antavat sinulle mahdollisuuden laittaa kuvan (tai jopa arvostelun) sivullesi kasvattamaan lhteesi nien mr. Valitse yhdest alla listatuista vaihtosehdoista:");
define("_TEXTLINK","Tekstilinkki");
define("_PROMOTE02","Yksi tapa linkitt arvostelukaavakkeeseen on yksinkertainen tekstilinkki:");
define("_HTMLCODE1","HTML-koodi, jota sinun tulisi tss tapauksessa kytt, on seuraava:");
define("_THENUMBER","Mr");
define("_IDREFER","HTML-lhdekoodissa viitataan sivusi tunnusnumeroon $sivunimi -tietokannassa. Varmista ett tm numero on mainittu.");
define("_BUTTONLINK","Nappilinkki");
define("_PROMOTE03","Jos etsit jotain muuta kuin tekstilinkki, saatat haluta kytt pient nappilinkki:");
define("_RATEIT","Arvostele tt sivua!");
define("_HTMLCODE2","Lhdekoodi edell mainitulle napille on:");
define("_REMOTEFORM","Ethallittu arvostelulomake");
define("_PROMOTE04","Jos huijaat tss, poistamme linkkisi. Tlt nytt nykyinen ethallittu arvostelulomake.");
define("_VOTE4THISSITE","nest tt sivua!");
define("_HTMLCODE3","Kytten tt lomaketta kyttjt voivat arvostella sivuasi suoraan sivultasi ja arvostelu talletetaan tnne. Ylloleva lomake ei toimi, mutta seuraava lhdekoodi toimii jos yksinkertaisesti leikkaat ja liimaat sen nettisivuusi. Lhdekoodi nkyy alla:");
define("_PROMOTE05","Kiitos! ja onnea arvosteluillesi!");
define("_STAFF","Yllpito");
define("_THANKSBROKEN","Kiitos ett autoit pitmn yll tmn luettelon kokonaisuutta.");
define("_SECURITYBROKEN","Turvallisuussyist kyttjtunnuksesi ja IP-osoitteesi talletetaan vkiaikaisesti.");
define("_THANKSFORINFO","Kiitos tiedoista.");
define("_LOOKTOREQUEST","Tarkistamme toiveesi pian.");
define("_SENDREQUEST","Lhet ehdotus");
define("_THANKSTOTAKETIME","Kiitos ajan kytstsi sivun arvosteluun tll");
define("_RETURNTO","Palaa");
define("_RATENOTE1","l nest samaa lhdett enemp kuin kerran.");
define("_RATENOTE2","Asteikko on 1 - 10, jossa 1 on huono ja 10 erinomainen.");
define("_RATENOTE3","Ole puolueeton nestyksesssi, jos kaikki saavat 1 tai 10, arvosteluista ei ole paljonkaan hyty.");
define("_RATENOTE5","l nest oman tai kilpailijasi lhteest.");
define("_YOUAREREGGED","Olet rekisterity kyttj ja olet kirjautunut sisn.");
define("_FEELFREE2ADD","Laita vapaasti kommentti tlle sivulle.");
define("_YOUARENOTREGGED","Et ole rekisterity kyttj tai et ole kirjautunut sisn.");
define("_IFYOUWEREREG","Jos olisit rekisteritynyt, voisit kommetoida tt sivua.");
define("_TITLE","Otsikko");
define("_MODIFY","Muokkaa");
define("_COMPLETEVOTE1","Your vote is appreciated.");
define("_COMPLETEVOTE2","You have already voted for this resource in the past $anonwaitdays day(s).");
define("_COMPLETEVOTE3","Vote for a resource only once.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE4","You cannot vote on a link you submitted.<br>All votes are logged and reviewed.");
define("_COMPLETEVOTE5","No rating selected - no vote tallied");
define("_COMPLETEVOTE6","Only one vote per IP address allowed every $outsidewaitdays day(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
